"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.signRequestSignature = void 0;
const query_string_1 = __importDefault(require("query-string"));
const crypto_js_1 = __importDefault(require("crypto-js"));
const interface_1 = require("../interface");
const METHOD_ENUM_MAP = {
    [interface_1.RequestMethod.DELETE]: interface_1.RequestMethod.DELETE,
    [interface_1.RequestMethod.GET]: interface_1.RequestMethod.GET,
    [interface_1.RequestMethod.POST]: interface_1.RequestMethod.POST,
    [interface_1.RequestMethod.PUT]: interface_1.RequestMethod.PUT,
};
/**
 *
 *  @param apiKeyCredentials, 登陆后可获取的用户apiKey
    @param requestPath, 请求路径, get接口需要添加参数，post参数不用添加
    @param method, 请求方法
    @param isoTimestamp, 时间戳
    @param data, 请求参数
 *  @returns string APEX-SIGNATURE 用于请求头进行后台验证
 */
const signRequestSignature = ({ apiKeyCredentials, requestPath, method, isoTimestamp, data, }) => {
    const messageString = new Date(isoTimestamp).getTime() +
        METHOD_ENUM_MAP[method] +
        requestPath +
        (!data ? "" : query_string_1.default.stringify(data, { encode: false }));
    const key = Buffer.from(apiKeyCredentials?.secret).toString("base64");
    const hash = crypto_js_1.default.HmacSHA256(messageString, key);
    const res = hash.toString(crypto_js_1.default.enc.Base64);
    return res;
};
exports.signRequestSignature = signRequestSignature;
