"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWithdrawal = void 0;
const __1 = require("../");
/**
 * @description post a new withdrawal
 *
 * @param {
 * @amount specifies the size of the withdrawal
 * @asset specifies the asset being withdrawn
 * @clientId specifies the clientId for the address
 * }
 * @param positionId specifies the associated position for the transfer
 */
const createWithdrawal = async ({ params, positionId, starkKeyPair, networkId, }) => {
    const clientId = params.clientId || (0, __1.generateRandomClientId)();
    let signature = params.signature;
    const time = Math.ceil(new Date().getTime() / 3600000) * 3600000 +
        14 * 24 * 60 * 60 * 1000;
    if (!signature) {
        if (!starkKeyPair) {
            throw new Error("Withdrawal is not signed and client was not initialized with starkPrivateKey");
        }
        let withdrawalToSign = {
            humanAmount: params.amount,
            expirationIsoTimestamp: `${time}`,
            clientId,
            positionId,
            ethAddress: params.ethAddress,
        };
        const starkWithdrawal = __1.SignableWithdrawal.fromWithdrawal(withdrawalToSign, networkId, params.asset);
        signature = await starkWithdrawal.sign(starkKeyPair);
        // 校验
        // const ifValid = await starkWithdrawal.verifySignature(signature, starkKeyPair?.publicKey, starkKeyPair?.publicKeyYCoordinate)
    }
    let withdrawal = {
        ...params,
        clientId,
        signature,
        ethAddress: params.ethAddress,
    };
    withdrawal.expiration = `${time}`;
    if (params.fee && params.realAmount) {
        withdrawal.amount = `${params.realAmount}`;
    }
    return withdrawal;
};
exports.createWithdrawal = createWithdrawal;
